.. |br| raw:: html

  <br/>

References
==========
.. [Reuter18]
    Reuter, B., Weber, M., Fackeldey, K., Röblitz, S., Garcia, M. E., |br|
    *Generalized Markov State Modeling Method for Nonequilibrium Biomolecular Dynamics: Exemplified on Amyloid β
    Conformational Dynamics Driven by an Oscillating Electric Field.*, |br|
    `Journal of Chemical Theory and Computation, 14(7), 3579–3594 <https://doi.org/10.1021/acs.jctc.8b00079>`__.

.. [Brandts02]
    Brandts, J. H., |br|
    *Matlab code for sorting real Schur forms*, |br|
    `Numer. Linear Algebra Appl., 9: 249-261 <https://doi.org/10.1002/nla.274>`__.

.. [Roeblitz13]
    S. Röblitz and M. Weber, |br|
    *Fuzzy spectral clustering by PCCA+: application to Markov state models and data classification.*, |br|
    `Adv Data Anal Classif 7, 147-179 (2013) <https://doi.org/10.1007/s11634-013-0134-6>`__.
